summaryrefslogtreecommitdiff
path: root/win32/build
diff options
context:
space:
mode:
authorAnatol Belski <ab@php.net>2016-10-30 15:22:45 +0100
committerAnatol Belski <ab@php.net>2016-10-30 15:22:45 +0100
commit78a164bad51fc99961f35802443dc65c12bc3fb2 (patch)
tree49422a30635ded5ec345f3efdf31ecbe2bbb02a6 /win32/build
parent36527eccbb793ef15f828ffa4261d9a862144f07 (diff)
downloadphp-git-78a164bad51fc99961f35802443dc65c12bc3fb2.tar.gz
rename the env setting target and reuse it for build-snap
Diffstat (limited to 'win32/build')
-rw-r--r--win32/build/Makefile7
-rw-r--r--win32/build/confutils.js8
2 files changed, 7 insertions, 8 deletions
diff --git a/win32/build/Makefile b/win32/build/Makefile
index 3ca135a484..9f389360d6 100644
--- a/win32/build/Makefile
+++ b/win32/build/Makefile
@@ -152,15 +152,14 @@ clean-pgo: clean-all
-del /f /q $(BUILD_DIR)\php-test-pack-$(PHP_VERSION_STRING).zip
!if $(PHP_TEST_INI_PATH) == ""
-test: set-test-env
+test: set-tmp-env
"$(BUILD_DIR)\php.exe" -d open_basedir= -d output_buffering=0 run-tests.php $(TESTS) -p "$(BUILD_DIR)\php.exe"
!else
-test: set-test-env
+test: set-tmp-env
"$(BUILD_DIR)\php.exe" -n -c $(PHP_TEST_INI_PATH) -d open_basedir= -d output_buffering=0 -d memory_limit=-1 run-tests.php -p "$(BUILD_DIR)\php.exe" -n -c $(PHP_TEST_INI_PATH) $(TESTS)
!endif
-build-snap: generated_files
- SET PATH=$(PATH);$(PHP_BUILD)\bin
+build-snap: set-tmp-env generated_files
@$(MAKE) "$(BUILD_DIR)\$(PHPDLL)"
-for %T in ($(SAPI_TARGETS)) do $(MAKE) /I /nologo "%T"
-for %T in ($(EXT_TARGETS)) do $(MAKE) /I /nologo "%T"
diff --git a/win32/build/confutils.js b/win32/build/confutils.js
index 2e46474a58..f7b40a77b8 100644
--- a/win32/build/confutils.js
+++ b/win32/build/confutils.js
@@ -1755,7 +1755,7 @@ function is_on_exclude_list_for_test_ini(list, name)
return false;
}
-function generate_test_php_ini()
+function generate_tmp_php_ini()
{
if ("no" == PHP_TEST_INI) {
/* Test ini generation is disabled. */
@@ -1833,7 +1833,7 @@ function generate_files()
STDOUT.WriteLine("Generating files...");
if (!MODE_PHPIZE) {
- generate_test_php_ini();
+ generate_tmp_php_ini();
}
generate_makefile();
if (!MODE_PHPIZE) {
@@ -2144,7 +2144,7 @@ function generate_makefile()
if (!MODE_PHPIZE) {
var val = "yes" == PHP_TEST_INI ? PHP_TEST_INI_PATH : "";
/* Be sure it's done after generate_test_php_ini(). */
MF.WriteLine("PHP_TEST_INI_PATH=\"" + val + "\"");
}
@@ -2207,7 +2207,7 @@ function generate_makefile()
}
}
}
- MF.WriteLine("set-test-env:");
+ MF.WriteLine("set-tmp-env:");
MF.WriteLine(" @set PATH=" + extra_path + ";$(PATH)");
MF.WriteBlankLines(2);
@@ -2144,7 +2144,7 @@ function generate_makefile()
if (!MODE_PHPIZE) {
var val = "yes" == PHP_TEST_INI ? PHP_TEST_INI_PATH : "";
- /* Be sure it's done after generate_test_php_ini(). */
+ /* Be sure it's done after generate_tmp_php_ini(). */
MF.WriteLine("PHP_TEST_INI_PATH=\"" + val + "\"");
}